;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "diff-hl" "20260427.2329"
  "Highlight uncommitted changes using VC."
  '((cl-lib "0.2")
    (emacs  "26.1"))
  :url "https://github.com/dgutov/diff-hl"
  :commit "7d873b2f58908de1ea2f499da9bf993e088953d7"
  :revdesc "7d873b2f5890"
  :keywords '("vc" "diff")
  :authors '(("Dmitry Gutov" . "dmitry@gutov.dev"))
  :maintainers '(("Dmitry Gutov" . "dmitry@gutov.dev")))
